# Montana Dinosaur Center Conflict of Interest Policy

## **Article 1. Purpose**

1. The purpose of this Board conflict of interest policy is to protect TMDC’s interests when it is contemplating entering into a transaction or arrangement that might benefit the private interests of an officer or director of TMDC or might result in possible excess benefit transaction.
2. This policy is intended to supplement, but not replace, any applicable state and federal laws governing conflicts of interest applicable to nonprofit and charitable organizations.
3. This policy is also intended to identify “independent” directors.

## **Article 2. Definitions**
1. **Interested person: **Any director, principal officer, or member of a committee with governing board delegated powers, who has a direct or indirect financial interest, as defined below, in an interested person.
2. **Financial interest: ** A person has a financial interest if the person has, directly or indirectly, through business, investment, or family:
    1. An ownership or investment interest in any entity with which TMDC has a transaction or arrangement, 
    2. A compensation arrangement with TMDC or with any entity or individual with which TMDC has a transaction or arrangement, or
    3. A potential ownership or investment interest in, or compensating arrangement with, any entity or individual with which TMDC is negotiating a transaction or arrangement.
Compensation includes direct and indirect remuneration as well as gifts or favors that are not insubstantial.
A financial interest is not necessarily a conflict of interest. A person who has a financial interest may have a conflict of interest only if the Board or Executive Committee decides that a conflict of interest exists, in accordance with this policy. 
3. **Independent Director:** A director shall be considered “independent” for the purposes of this policy if he or she is “independent” as defined in the instructions for the IRS 990 form or, until such definition is available, the director 
    4. is not, and has not been for a period of at least three years, an employee of TMDC or any entity in which TMDC has a financial interest; 
    5. does not directly or indirectly have a significant business relationship with TMDC, which might affect independence in decision-making; 
    6. is not employed as an executive of another corporation where any of TMDC’s executive officers or employees serve on that corporation’s compensation committee; and 
    7. does not have an immediate family member who is an executive officer or employee of TMDC or who holds a position that has a significant financial relationship with TMDC.  \
4. **Nonfinancial interest:** is a nonfinancial interest that might influence an officer’s, director’s, or committee member’s participation or vote in an action of the officer’s, director’s, or committee member’s duties: 
    8. The person’s relationship as an unpaid volunteer, officer or director of an organization that may be affected, directly or indirectly, by action to be taken, or not taken, by TMDC 
    9. The person’s personal, political, religious, friendship, or personal relationships which may be affected by an action to be taken, or not taken, by TMDC. 

## **Article 3. Procedures**

1. **Duty to Disclose** In connection with any actual or possible conflict of interest, an interested person must disclose the existence of any financial interest and be given the opportunity to disclose all material facts to the Board or Executive Committee. 
2. **Disclosure of non-financial interests**. Directors shall disclose non-financial interests generally in their annual statement, and specifically as individual interests arise. Non-financial interests are expected, and shall not be reviewed unless a Board member (including the affected member) requests that the interest be reviewed under the Conflict of Interest Policy. 
3. **Recusal of Self**. Any director may recuse himself or herself at any time from involvement in any decision or discussion in which the director believes he or she has or may have a conflict of interest, without going through the process for determining whether a conflict of interest exists. 
4. **Determining Whether a Conflict of Interest Exists.** After disclosure of the financial interest all material facts will be disclosed and reviewed, including discussion with the interested person. Upon request by a Board member the material facts of a nonfinancial interest will be reviewed, including discussion with the interested party. Then the potentially conflicted Member shall leave the Board or Executive Committee meeting while the determination of a conflict of interest is discussed and voted upon. The remaining Board or Executive Committee members shall decide if a conflict of interest exists.  \
5. **Procedures for Addressing the Conflict of Interest** 
    1. An interested person may make a presentation at the Board or Executive Committee meeting, but after the presentation, he/she shall leave the meeting during the discussion of, and the vote on, the transaction, arrangement, or other matter involving the possible conflict of interest. 
    2. The Chairperson of the Board or Executive Committee shall, if appropriate, appoint a disinterested person or committee to investigate alternatives to the proposed transaction or arrangement. 
    3. After exercising due diligence, the Board or Executive Committee shall determine whether TMDC can obtain with reasonable efforts a more advantageous transaction or arrangement from a person or entity that would not give rise to a financial conflict of interest. 
    4. If a more advantageous transaction or arrangement is not reasonably possible under circumstances not producing a financial conflict of interest, the Board or Executive Committee shall determine by a majority vote of the disinterested directors whether the transaction or arrangement is in TMDC's best interest, for its own benefit, and whether it is fair and reasonable. In conformity with the above determination, it shall make its decision as to whether to enter into the transaction or arrangement.  \

6. **Violations of the Conflicts of Interest Policy** 
    1. If the Board or Executive Committee has reasonable cause to believe a member has failed to disclose actual or possible conflicts of interest, it shall inform the member of the basis for such belief and afford the member an opportunity to explain the alleged failure to disclose. 
    2. If, after hearing the member's response and after making further investigation as warranted by the circumstances, the Board or Executive Committee determines the member has failed to disclose an actual or possible conflict of interest, it shall take appropriate disciplinary and corrective action. 

## **Article 4. Records of Proceedings** 
The minutes of the Board and all committees with board delegated powers shall contain: 

    1. The names of the persons who disclosed or otherwise were found to have a financial interest in connection with an actual or possible conflict of interest, the nature of the financial interest, any action taken to determine whether a conflict of interest was present, and the Board's or Executive Committee's decision as to whether a conflict of interest in fact existed. 
    2. The names of the persons who were present for discussions and votes relating to the transaction or arrangement, the content of the discussion, including any alternatives to the proposed transaction or arrangement, and a record of any votes taken in connection with the proceedings. 


## **Article 5.  Compensation **



1. A voting member of the Board who receives compensation, directly or indirectly, from TMDC for services is precluded from voting on matters pertaining to that member's compensation. 
2. A voting member of any committee whose jurisdiction includes compensation matters and who receives compensation, directly or indirectly, from TMDC for services is precluded from voting on matters pertaining to that member's compensation. 
3. No voting member of the Board or any committee whose jurisdiction includes compensation matters and who receives compensation, directly or indirectly, from TMDC, either individually or collectively, is prohibited from providing information to any committee regarding compensation.

## **Article 6. Annual Statements**

1. Each director, principal officer and member of a committee with Board delegated powers shall annually sign a statement which affirms such person: 
    1. Has received a copy of the conflict of interest policy, 
    2. Has read and understands the policy, 
    3. Has agreed to comply with the policy, and d. Understands TMDC is charitable and in order to maintain its federal tax exemption it must engage primarily in activities which accomplish one or more of its tax-exempt purposes. 
2. Each voting member of the Board shall annually sign a statement which declares whether such person is an independent director.
3. If at any time during the year, the information in the annual statement changes materially, the director shall disclose such changes and revise the annual disclosure form. 
4. The Executive Committee shall regularly and consistently monitor and enforce compliance with this policy by reviewing annual statements and taking such other actions as are necessary for effective oversight. 

## **Article 7. Periodic Reviews **

To ensure TMDC operates in a manner consistent with charitable purposes and does not engage in activities that could jeopardize its tax-exempt status, periodic reviews shall be conducted. The periodic reviews shall, at a minimum, include the following subjects:  \

  1. Whether compensation arrangements and benefits are reasonable, based on competent survey information (if reasonably available), and the result of arm's length bargaining. 
  2. Whether partnerships, joint ventures, and arrangements with management organizations, if any, conform to TMDC's written policies, are properly recorded, reflect reasonable investment or payments for goods and services, further charitable purposes and do not result in inurement or impermissible private benefit or in an excess benefit transaction. 

## **Article 8. Use of Outside Experts **

When conducting the periodic reviews as provided for in Article VII, TMDC may, but need not, use outside advisors. If outside experts are used, their use shall not relieve the Board of its responsibility for ensuring periodic reviews are conducted. 

Revision History by the TMDC Board 

Initial Conflict of Interest policy adopted _____________  ____, 2020 


Montana Dinosaur Center Director & Officer Conflict of Interest Statement 

1. Name: ____________________________________ 		Date: ____________________ 
Are you a member in Good Standing? Yes No 
What organization or other membership affiliation do you represent? _________________________ 
Position: 
	Are you a voting Director? Yes No 
	Are you an Officer? Yes No 
	If you are an Officer, which Officer position do you hold:_____________________________. 
2. I affirm the following: 
	I have received a copy of the TMDC Conflict of Interest Policy. _________ (initial) 
	I have read and understand the policy. _________ (initial)
	I agree to comply with the policy. _________ (initial) 
	I have reviewed the Board Member Job Description. _________ (initial) 
	I understand that TMDC is charitable and in order to maintain its federal tax exemption it must engage primarily in activities which accomplish one or more of tax-exempt purposes. _________ (initial) \
Disclosures:
1. Do you have a financial interest (current or potential), including a compensation arrangement, as defined in the Conflict of Interest policy with TMDC? Yes No 
    1. If yes, please describe it: ____________________________________________ 
    2. If yes, has the financial interest been disclosed, as provided in the Conflict of Interest policy? Yes No 
2. In the past, have you had a financial interest, including a compensation arrangement, as defined in the Conflict of Interest policy with TMDC? Yes No 
    1. If yes, please describe it, including when (approximately): _______________________________________________ 
    2. If yes, has the financial interest been disclosed, as provided in the Conflict of Interest policy? Yes No 
3. Are you an independent director, as defined in the Conflict of Interest policy? Yes No 
    * If you are not independent, why? ______________________________________ 

_______________________________________________________ 
Signature of Director 										Date

Date of Review by Executive Committee: _____________________________
